@@ -1,5 +1,5 @@
 ;;; jde-db.el -- Debugger mode for jdb.
-;; $Revision: 1.1 $ $Date: 2000/08/13 13:43:58 $ 
+;; $Revision: 1.2 $ $Date: 2000/10/06 08:51:20 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -236,7 +236,7 @@ Property Value field. You can specify as many properties as you like."
   :group 'jde-db-options
   :type '(cons boolean
 	       (list
-		(string :tag "Ouput File Path")
+		(string :tag "Output File Path")
 		(integer :tag "Stack Trace Depth")
 		(integer :tag "Allocation Sites")
 		(radio-button-choice :format "%t \n%v"
@@ -1119,6 +1119,9 @@ file in the current buffer."
 
 ;; Change History
 ;; $Log: jde-db.el,v $
+;; Revision 1.2  2000/10/06 08:51:20  youngs
+;; Martin's Monster Mega typo patch
+;;
 ;; Revision 1.1  2000/08/13 13:43:58  michaels
 ;; Initial checkin.
 ;;
@@ -1171,7 +1174,7 @@ file in the current buffer."
 ;; debugger breakpoint messages.
 ;;
 ;; Revision 1.49  1999/02/26 15:52:52  paulk
-;; Catch non-existant directory errors when searching for source
+;; Catch non-existent directory errors when searching for source
 ;; files and packages. Thanks to Thanh Nguyen <Thanh.Nguyen@Eng.Sun.COM>
 ;; for finding and providing a fix for this bug.
 ;;
@@ -1374,4 +1377,4 @@ file in the current buffer."
 ;; Initial revision
 ;;
 
-;;; end of jde-db.el
\ No newline at end of file
+;;; end of jde-db.el
